==============================================================
MRdataset : unified interface to various neuroimaging datasets
==============================================================

.. image:: https://img.shields.io/pypi/v/MRdataset.svg
        :target: https://pypi.python.org/pypi/MRdataset

.. image:: ./docs/images/hierarchy.jpg

* A unified interface to various neuroimaging datasets such as DICOM, BIDS and any other generic format etc.
* Documentation: https://open-minds-lab.github.io/MRdataset/



